# Composition Analyzer Featurizer (CAF)

![PR](https://img.shields.io/badge/PR-Welcome-29ab47ff)
![PyPI](https://img.shields.io/pypi/v/composition-analyzer-featurizer)
![PythonVersion](https://img.shields.io/pypi/pyversions/composition-analyzer-featurizer)

CAF helps solid-state chemists and materials scientists in generating compositional training data for compounds. Both experimentalists and novices can use this tool with a basic understanding of Python. The codebase is designed for easy customization.

Features:

- Generate compositional descriptors for binary, ternary, and quaternary compounds from Excel or `.cif` files
- Filter and sort chemical formulas using four different methods
- Merge Excel files
- No coding required

## Publications

If you use `CAF` in your scientific publication, please cite the software package:

> **Digital Discovery**, https://doi.org/10.1039/D4DD00332B

as well as the Oliynyk elemental property dataset:

> **Data in Brief**, https://doi.org/10.1016/j.dib.2024.110178

## Getting started

To learn more, please read the official documentation at https://github.com/bobleesj/composition-analyzer-featurizer.

## Acknowledgements

`CAF` is built and maintained with [scikit-package](https://scikit-package.github.io/scikit-package/).
